@@ -11,21 +11,17 @@
 
 #include <aws/http/http.h>
 
+#include <aws/sdkutils/sdkutils.h>
+
 #include <aws/common/error.h>
 
 #define AWS_DEFINE_ERROR_INFO_AUTH(CODE, STR) AWS_DEFINE_ERROR_INFO(CODE, STR, "aws-c-auth")
 
 /* clang-format off */
 static struct aws_error_info s_errors[] = {
-    AWS_DEFINE_ERROR_INFO_AUTH(
-        AWS_AUTH_PROFILE_PARSE_RECOVERABLE_ERROR,
-        "Recoverable error while parsing an aws profile file"),
-    AWS_DEFINE_ERROR_INFO_AUTH(
-        AWS_AUTH_PROFILE_PARSE_FATAL_ERROR,
-        "Fatal error while parsing an aws profile file"),
     AWS_DEFINE_ERROR_INFO_AUTH(
         AWS_AUTH_SIGNING_UNSUPPORTED_ALGORITHM,
-        "Attempt to sign an http request with an unusupported version of the AWS signing protocol"),
+        "Attempt to sign an http request with an unsupported version of the AWS signing protocol"),
     AWS_DEFINE_ERROR_INFO_AUTH(
         AWS_AUTH_SIGNING_MISMATCHED_CONFIGURATION,
         "Attempt to sign an http request with a signing configuration unrecognized by the invoked signer"),
@@ -137,6 +133,7 @@ void aws_auth_library_init(struct aws_allocator *allocator) {
         s_library_allocator = aws_default_allocator();
     }
 
+    aws_sdkutils_library_init(s_library_allocator);
     aws_cal_library_init(s_library_allocator);
     aws_http_library_init(s_library_allocator);
 
@@ -164,5 +161,6 @@ void aws_auth_library_clean_up(void) {
     aws_unregister_error_info(&s_error_list);
     aws_http_library_clean_up();
     aws_cal_library_clean_up();
+    aws_sdkutils_library_clean_up();
     s_library_allocator = NULL;
 }
