@@ -15,10 +15,10 @@
 
 #pragma once
 
-#include <s2n.h>
+#include "api/s2n.h"
 #include <stdio.h>
 #include <stdbool.h>
-#include <utils/s2n_ensure.h>
+#include "utils/s2n_ensure.h"
 
 /*
  * To easily retrieve error types, we split error values into two parts.
@@ -206,6 +206,9 @@ typedef enum {
     S2N_ERR_PQ_DISABLED,
     S2N_ERR_INVALID_CERT_STATE,
     S2N_ERR_INVALID_EARLY_DATA_STATE,
+    S2N_ERR_PKEY_CTX_INIT,
+    S2N_ERR_FORK_DETECTION_INIT,
+    S2N_ERR_RETRIEVE_FORK_GENERATION_NUMBER,
     S2N_ERR_T_INTERNAL_END,
 
     /* S2N_ERR_T_USAGE */
@@ -265,7 +268,6 @@ typedef enum {
     S2N_ERR_ASYNC_ALREADY_PERFORMED,
     S2N_ERR_ASYNC_NOT_PERFORMED,
     S2N_ERR_ASYNC_WRONG_CONNECTION,
-    S2N_ERR_ASYNC_APPLY_WHILE_INVOKING,
     S2N_ERR_ASYNC_ALREADY_APPLIED,
     S2N_ERR_UNSUPPORTED_WITH_QUIC,
     S2N_ERR_DUPLICATE_PSK_IDENTITIES,
@@ -294,12 +296,18 @@ extern __thread const char *s2n_debug_str;
 
 #define _S2N_DEBUG_LINE     "Error encountered in " __FILE__ ":" STRING__LINE__
 #define _S2N_ERROR( x )     do { s2n_debug_str = _S2N_DEBUG_LINE; s2n_errno = ( x ); s2n_calculate_stacktrace(); } while (0)
-#define S2N_ERROR( x )      do { _S2N_ERROR( ( x ) ); return -1; } while (0)
 #define S2N_ERROR_PRESERVE_ERRNO() do { return -1; } while (0)
-#define S2N_ERROR_PTR( x )  do { _S2N_ERROR( ( x ) ); return NULL; } while (0)
-#define S2N_ERROR_IF( cond , x ) do { if ( cond ) { S2N_ERROR( x ); }} while (0)
 #define S2N_ERROR_IS_BLOCKING( x )    ( s2n_error_get_type(x) == S2N_ERR_T_BLOCKED )
 
+/* DEPRECATED: use POSIX_BAIL instead */
+#define S2N_ERROR( x )      do { _S2N_ERROR( ( x ) ); return -1; } while (0)
+
+/* DEPRECATED: use PTR_BAIL instead */
+#define S2N_ERROR_PTR( x )  do { _S2N_ERROR( ( x ) ); return NULL; } while (0)
+
+/* DEPRECATED: use POSIX_ENSURE instead */
+#define S2N_ERROR_IF( cond , x ) do { if ( cond ) { S2N_ERROR( x ); }} while (0)
+
 /** Calculate and print stacktraces */
 struct s2n_stacktrace {
   char **trace;
